function ptda = consolidatePitches(pitch, time, amp, bpm, tol)
%ptda = consolidatePitches(oldPitch, oldTime, oldAmps[, tol])
%tol is smallest note allowed (default 16th note)
%combines similar pitches
%ptda = [pitch startTime duration amp]

tolVar = .45;
if nargin == 4
    tol = 16;
end
tol = 60/bpm/(tol-(tol*tolVar));


pitch = round(pitch);
ptda = [];
curTime = 0;
numNotes = 1;

for ii = 1:length(pitch)

    if size(ptda) == [0 0]
        %first note
        ptda(numNotes,:) = [pitch(ii) time(ii) 0 amp(ii)];

    elseif pitch(ii-1) == pitch(ii)
        %add to duration
        curTime = time(ii);
        %check if max vel has been reached
        if ptda(numNotes,4) < amp(ii)
            ptda(numNotes,4) = amp(ii);
        end
    else
        %set duration of last note
        dur = curTime - ptda(numNotes,2);
        ptda(numNotes,3) = curTime - ptda(numNotes,2);
        
        %start new note
        if dur >= tol
            numNotes = numNotes + 1;
        end
        ptda(numNotes,:) = [pitch(ii) time(ii) 0 amp(ii)];
        curTime = time(ii);
    end

end
        

%set duration of last note
ptda(numNotes,3) = curTime - ptda(numNotes,2);
%set velocity to 0:120
ptda(:,4) = ptda(:,4)*127;
ptda(:,4) = ptda(:,4)+(120-max(ptda(:,4)));

%this is the notematrix [0 0 1 midiNum vel onset dur]
ptda = [zeros(length(ptda),2) ones(length(ptda),1) ptda(:,1) ptda(:,4) ptda(:,2) ptda(:,3)];


for ii = 1:size(ptda,1)
    %set vel to 0 for rests
    if ptda(ii,4) == 0
        ptda(ii,5) = 0;
    end
    
    %set the beat onset and duration
    ptda(ii,1:2) = (ptda(ii,6:7)*bpm)/60;    
end

%round the midi velocities since they must be whole numbers
ptda(:,5) = round(ptda(:,5));

%cut off rests that are the last notes
while ptda(end,4) == 0
    ptda = ptda(1:end-1,:);
end
while ptda(1,4) == 0
    ptda = ptda(2:end,:);
end